==> screenpy-1.0.0.tar.gz: screenpy-1.0.0/screenpy/actions/switch_to.py <==
"""
An action to switch the driver's frame of reference. An actor must possess
the ability to BrowseTheWeb to perform this action. An actor performs this
action like so:

    the_actor.attempts_to(SwitchTo.the(ORDERS_FRAME))

    the_actor.attempts_to(SwitchTo(THE_ORDERS_FRAME))

    the_actor.attempts_to(SwitchTo.default())
"""


from typing import Optional

from ..abilities import BrowseTheWeb
from ..actor import Actor
from ..pacing import beat
from ..target import Target
from .base_action import BaseAction


class SwitchTo(BaseAction):
    """
    Switches to something, most likely an iframe, or back to default. A
    SwitchTo action is expected to be instantiated by its static
    |SwitchTo.the| or |SwitchTo.default| methods, or on its own. A typical
    invocation might look like:

        SwitchTo.the(ORDERS_FRAME)

        SwitchTo.default()

    It can then be passed along to the |Actor| to perform the action.
    """

    @staticmethod
    def the(target: Target) -> "SwitchTo":
        """
        Provide the element to switch to.

        Args:
            target: the |Target| describing the element to switch to.

        Returns:
            |SwitchTo|
        """
        return SwitchTo(target)

    @staticmethod
    def default() -> "SwitchTo":
        """
        Switches back to the default frame, the browser window.

        Returns:
            |SwitchTo|
        """
        return SwitchTo(None)

    @beat("{0} switches to the {target}.")
    def perform_as(self, the_actor: Actor) -> None:
        """
        Asks the actor to perform the SwitchTo action.

        Args:
            the_actor: The |Actor| who will perform this action.

        Raises:
            |UnableToPerformError|: the actor does not have the ability to
                |BrowseTheWeb|.
        """
        if self.target is None:
            the_actor.uses_ability_to(BrowseTheWeb).to_switch_to_default()
        else:
            the_actor.uses_ability_to(BrowseTheWeb).to_switch_to(self.target)

    def __init__(self, target: Optional[Target]) -> None:
        self.target = target

==> screenpy-2.0.1.tar.gz: screenpy-2.0.1/screenpy/actions/switch_to.py <==
"""
An action to switch the driver's frame of reference. An actor must possess
the ability to BrowseTheWeb to perform this action. An actor performs this
action like so:

    the_actor.attempts_to(SwitchTo.the(ORDERS_FRAME))

    the_actor.attempts_to(SwitchTo(THE_ORDERS_FRAME))

    the_actor.attempts_to(SwitchTo.default())
"""


from typing import Optional

from ..abilities import BrowseTheWeb
from ..actor import Actor
from ..pacing import beat
from ..target import Target
from .base_action import BaseAction


class SwitchTo(BaseAction):
    """
    Switch to an element, most likely an iframe, or back to default. A
    SwitchTo action is expected to be instantiated by its static
    |SwitchTo.the| or |SwitchTo.default| methods, or on its own with a target.
    Typical invocations might look like:

        SwitchTo(THE_ORDERS_FRAME)

        SwitchTo.the(ORDERS_FRAME)

        SwitchTo.default()

    It can then be passed along to the |Actor| to perform the action.
    """

    @staticmethod
    def the(target: Target) -> "SwitchTo":
        """
        Specify the target to switch to.

        Args:
            target: the |Target| describing the element to switch to.

        Returns:
            |SwitchTo|
        """
        return SwitchTo(target)

    @staticmethod
    def default() -> "SwitchTo":
        """
        Switch back to the default frame, the browser window.

        Returns:
            |SwitchTo|
        """
        return SwitchTo(None)

    @beat("{0} switches to the {target}.")
    def perform_as(self, the_actor: Actor) -> None:
        """
        Direct the actor to switch to the specified element, or back to
        the default.

        Args:
            the_actor: The |Actor| who will perform this action.

        Raises:
            |UnableToPerform|: the actor does not have the ability to
                |BrowseTheWeb|.
        """
        browser = the_actor.ability_to(BrowseTheWeb).browser
        if self.target is None:
            browser.switch_to.default_content()
        else:
            browser.switch_to.frame(self.target.found_by(the_actor))

    def __init__(self, target: Optional[Target]) -> None:
        self.target = target
